| get_ci | R Documentation |
bootci Objectget_ci() extracts the confidence intervals from the output of a call to \pkgfunbootboot.ci or fwb.ci() in a clean way. Normally the confidence intervals can be a bit challenging to extract because of the unusual structure of the object.
get_ci(x, type = "all")
x |
a |
type |
the type of confidence intervals to extract. Only those available in |
A list with an entry for each confidence interval type; each entry is a numeric vector of length 2 with names "L" and "U" for the lower and upper interval bounds, respectively. The "conf" attribute contains the confidence level.
fwb.ci(), confint.fwb(), \pkgfunbootboot.ci
#See example at help("fwb.ci")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.