| plot.fwb | R Documentation |
plot.fwb() takes an <fwb> object and produces plots for the bootstrap replicates of the statistic of interest.
## S3 method for class 'fwb'
plot(
x,
index = 1L,
qdist = "norm",
nclass = NULL,
df,
type = c("hist", "qq"),
...
)
x |
an |
index |
the index of the position of the quantity of interest in |
qdist |
|
nclass |
when a histogram is requested (as it is by default; see |
df |
if |
type |
the type of plot to display. Allowable options include |
... |
ignored. |
This function can produces two side-by-side plots: a histogram of the bootstrap replicates and a Q-Q plot of the bootstrap replicates against theoretical quantiles of a supplied distribution (normal or chi-squared). For the histogram, a vertical dotted line indicates the position of the estimate computed in the original sample. For the Q-Q plot, the expected line is plotted.
x is returned invisibly.
fwb(), summary.fwb(), \pkgfunbootplot.boot, hist(), qqplot()
# See examples at `help("fwb")`
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.